@@ -55,6 +55,7 @@ typedef const unsigned short *LPCWCH, *PCWCH, *LPCWSTR, *PCWSTR, *LPCOLESTR;
 typedef unsigned int UINT_PTR;
 // basic stuff
 typedef void * HANDLE;
+typedef HANDLE HWND;
 typedef unsigned long HKEY;
 // some gdi
 typedef unsigned long COLORREF;
@@ -867,4 +868,8 @@ typedef struct tagVS_FIXEDFILEINFO {
 #  pragma pack()
 #endif
 
+#ifndef SHGFP_TYPE_CURRENT
+  #define SHGFP_TYPE_CURRENT 0
+#endif
+
 #endif
