@@ -27,6 +27,12 @@ using namespace std;
 #define ALIGN(dwToAlign, dwAlignOn) dwToAlign = (dwToAlign%dwAlignOn == 0) ? dwToAlign : dwToAlign - (dwToAlign%dwAlignOn) + dwAlignOn
 #define RALIGN(dwToAlign, dwAlignOn) ((dwToAlign%dwAlignOn == 0) ? dwToAlign : dwToAlign - (dwToAlign%dwAlignOn) + dwAlignOn)
 
+#ifndef _WIN32
+static inline ULONG ConvertEndianness(ULONG u) {
+  return FIX_ENDIAN_INT32(u);
+}
+#endif
+
 static inline DWORD ConvertEndianness(DWORD d) {
   return FIX_ENDIAN_INT32(d);
 }
@@ -344,6 +350,46 @@ int CResourceEditor::GetResourceSizeA(char* szType, char* szName, LANGID wLangua
   return result;
 }
 
+// Returns the offset of the requested resource in the original PE
+// Returns -1 if the requested resource can't be found
+DWORD CResourceEditor::GetResourceOffsetW(WCHAR* szType, WCHAR* szName, LANGID wLanguage) {
+  CResourceDirectory* nameDir = 0;
+  CResourceDirectory* langDir = 0;
+  CResourceDataEntry* data = 0;
+
+  int i = m_cResDir->Find(szType);
+  if (i > -1) {
+    nameDir = m_cResDir->GetEntry(i)->GetSubDirectory();
+    i = nameDir->Find(szName);
+    if (i > -1) {
+      langDir = nameDir->GetEntry(i)->GetSubDirectory();
+      i = 0;
+      if (wLanguage)
+        i = langDir->Find(wLanguage);
+      if (i > -1) {
+        data = langDir->GetEntry(i)->GetDataEntry();
+      }
+    }
+  }
+
+  if (data)
+    return data->GetOffset();
+  else
+    return DWORD(-1);
+}
+
+DWORD CResourceEditor::GetResourceOffsetA(char* szType, char* szName, LANGID wLanguage) {
+  WCHAR* szwType = ResStringToUnicode(szType);
+  WCHAR* szwName = ResStringToUnicode(szName);
+
+  DWORD result = GetResourceOffsetW(szwType, szwName, wLanguage);
+
+  FreeUnicodeResString(szwType);
+  FreeUnicodeResString(szwName);
+
+  return result;
+}
+
 void CResourceEditor::FreeResource(BYTE* pbResource)
 {
   if (pbResource)
@@ -541,16 +587,16 @@ CResourceDirectory* CResourceEditor::ScanDirectory(PRESOURCE_DIRECTORY rdRoot, P
 
   for (int i = 0; i < entries; i++) {
     MY_IMAGE_RESOURCE_DIRECTORY_ENTRY rd = rdToScan->Entries[i];
-    rd.OffsetToData = ConvertEndianness(rd.OffsetToData);
-    rd.Name = ConvertEndianness(rd.Name);
+    rd.UOffset.OffsetToData = ConvertEndianness(rd.UOffset.OffsetToData);
+    rd.UName.Name = ConvertEndianness(rd.UName.Name);
 
     // If this entry points to data entry get a pointer to it
-    if (!rd.DirectoryOffset.DataIsDirectory)
-      rde = PIMAGE_RESOURCE_DATA_ENTRY(rd.OffsetToData + (BYTE*)rdRoot);
+    if (!rd.UOffset.DirectoryOffset.DataIsDirectory)
+      rde = PIMAGE_RESOURCE_DATA_ENTRY(rd.UOffset.OffsetToData + (BYTE*)rdRoot);
 
     // If this entry has a name, translate it from Unicode
-    if (rd.NameString.NameIsString) {
-      PIMAGE_RESOURCE_DIR_STRING_U rds = PIMAGE_RESOURCE_DIR_STRING_U(rd.NameString.NameOffset + (char*)rdRoot);
+    if (rd.UName.NameString.NameIsString) {
+      PIMAGE_RESOURCE_DIR_STRING_U rds = PIMAGE_RESOURCE_DIR_STRING_U(rd.UName.NameString.NameOffset + (char*)rdRoot);
 
       size_t nameSize = ConvertEndianness(rds->Length);
       szName = new WCHAR[nameSize+1];
@@ -559,29 +605,37 @@ CResourceDirectory* CResourceEditor::ScanDirectory(PRESOURCE_DIRECTORY rdRoot, P
     }
     // Else, set the name to this entry's id
     else
-      szName = MAKEINTRESOURCEW(ConvertEndianness(rdToScan->Entries[i].Id));
+      szName = MAKEINTRESOURCEW(ConvertEndianness(rdToScan->Entries[i].UName.Id));
 
-    if (rd.DirectoryOffset.DataIsDirectory)
+    if (rd.UOffset.DirectoryOffset.DataIsDirectory)
+    {
       rdc->AddEntry(
         new CResourceDirectoryEntry(
           szName,
           ScanDirectory(
             rdRoot,
-            PRESOURCE_DIRECTORY(rd.DirectoryOffset.OffsetToDirectory + (BYTE*)rdRoot)
+            PRESOURCE_DIRECTORY(rd.UOffset.DirectoryOffset.OffsetToDirectory + (LPBYTE)rdRoot)
           )
         )
       );
+    }
     else
+    {
+      LPBYTE pbData = (LPBYTE)rdRoot + ConvertEndianness(rde->OffsetToData) - m_dwResourceSectionVA;
+      DWORD dwOffset = DWORD(pbData - m_pbPE);
+
       rdc->AddEntry(
         new CResourceDirectoryEntry(
           szName,
           new CResourceDataEntry(
-            (BYTE*)rdRoot + ConvertEndianness(rde->OffsetToData) - m_dwResourceSectionVA,
+            pbData,
             ConvertEndianness(rde->Size),
-            ConvertEndianness(rde->CodePage)
+            ConvertEndianness(rde->CodePage),
+            dwOffset
           )
         )
       );
+    }
 
     // Delete the dynamicly allocated name if it is a name and not an id
     if (!IS_INTRESOURCE(szName))
@@ -626,10 +680,10 @@ void CResourceEditor::WriteRsrcSec(BYTE* pbRsrcSec) {
 
       MY_IMAGE_RESOURCE_DIRECTORY_ENTRY rDirE;
       ZeroMemory(&rDirE, sizeof(rDirE));
-      rDirE.DirectoryOffset.DataIsDirectory = crd->GetEntry(i)->IsDataDirectory();
-      rDirE.Id = crd->GetEntry(i)->HasName() ? 0 : crd->GetEntry(i)->GetId();
-      rDirE.Id = ConvertEndianness(rDirE.Id);
-      rDirE.NameString.NameIsString = (crd->GetEntry(i)->HasName()) ? 1 : 0;
+      rDirE.UOffset.DirectoryOffset.DataIsDirectory = crd->GetEntry(i)->IsDataDirectory();
+      rDirE.UName.Id = crd->GetEntry(i)->HasName() ? 0 : crd->GetEntry(i)->GetId();
+      rDirE.UName.Id = ConvertEndianness(rDirE.UName.Id);
+      rDirE.UName.NameString.NameIsString = (crd->GetEntry(i)->HasName()) ? 1 : 0;
 
       CopyMemory(seeker, &rDirE, sizeof(MY_IMAGE_RESOURCE_DIRECTORY_ENTRY));
       crd->GetEntry(i)->m_dwWrittenAt = DWORD(seeker);
@@ -660,7 +714,7 @@ void CResourceEditor::WriteRsrcSec(BYTE* pbRsrcSec) {
   while (!qStrings.empty()) {
     CResourceDirectoryEntry* cRDirE = qStrings.front();
 
-    PMY_IMAGE_RESOURCE_DIRECTORY_ENTRY(cRDirE->m_dwWrittenAt)->NameString.NameOffset = ConvertEndianness(DWORD(seeker) - DWORD(pbRsrcSec));
+    PMY_IMAGE_RESOURCE_DIRECTORY_ENTRY(cRDirE->m_dwWrittenAt)->UName.NameString.NameOffset = ConvertEndianness(DWORD(seeker) - DWORD(pbRsrcSec));
 
     WCHAR* szName = cRDirE->GetName();
     WORD iLen = winchar_strlen(szName) + 1;
@@ -699,13 +753,13 @@ void CResourceEditor::SetOffsets(CResourceDirectory* resDir, DWORD newResDirAt)
   for (int i = 0; i < resDir->CountEntries(); i++) {
     PMY_IMAGE_RESOURCE_DIRECTORY_ENTRY rde = PMY_IMAGE_RESOURCE_DIRECTORY_ENTRY(resDir->GetEntry(i)->m_dwWrittenAt);
     if (resDir->GetEntry(i)->IsDataDirectory()) {
-      rde->DirectoryOffset.DataIsDirectory = 1;
-      rde->DirectoryOffset.OffsetToDirectory = resDir->GetEntry(i)->GetSubDirectory()->m_dwWrittenAt - newResDirAt;
-      rde->OffsetToData = ConvertEndianness(rde->OffsetToData);
+      rde->UOffset.DirectoryOffset.DataIsDirectory = 1;
+      rde->UOffset.DirectoryOffset.OffsetToDirectory = resDir->GetEntry(i)->GetSubDirectory()->m_dwWrittenAt - newResDirAt;
+      rde->UOffset.OffsetToData = ConvertEndianness(rde->UOffset.OffsetToData);
       SetOffsets(resDir->GetEntry(i)->GetSubDirectory(), newResDirAt);
     }
     else {
-      rde->OffsetToData = ConvertEndianness(resDir->GetEntry(i)->GetDataEntry()->m_dwWrittenAt - newResDirAt);
+      rde->UOffset.OffsetToData = ConvertEndianness(resDir->GetEntry(i)->GetDataEntry()->m_dwWrittenAt - newResDirAt);
     }
   }
 }
@@ -972,9 +1026,10 @@ CResourceDataEntry* CResourceDirectoryEntry::GetDataEntry() {
 // Construction/Destruction
 //////////////////////////////////////////////////////////////////////
 
-CResourceDataEntry::CResourceDataEntry(BYTE* pbData, DWORD dwSize, DWORD dwCodePage) {
+CResourceDataEntry::CResourceDataEntry(BYTE* pbData, DWORD dwSize, DWORD dwCodePage, DWORD dwOffset) {
   m_pbData = 0;
   SetData(pbData, dwSize, dwCodePage);
+  m_dwOffset = dwOffset;
 }
 
 CResourceDataEntry::~CResourceDataEntry() {
@@ -1002,6 +1057,7 @@ void CResourceDataEntry::SetData(BYTE* pbData, DWORD dwSize, DWORD dwCodePage) {
   CopyMemory(m_pbData, pbData, dwSize);
   m_dwSize = dwSize;
   m_dwCodePage = dwCodePage;
+  m_dwOffset = DWORD(-1); // unset
 }
 
 DWORD CResourceDataEntry::GetSize() {
@@ -1011,3 +1067,7 @@ DWORD CResourceDataEntry::GetSize() {
 DWORD CResourceDataEntry::GetCodePage() {
   return m_dwCodePage;
 }
+
+DWORD CResourceDataEntry::GetOffset() {
+  return m_dwOffset;
+}
