@@ -1,3 +1,19 @@
+/*
+ * clzma.cpp
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #include <algorithm> // for std::min
 #include "clzma.h"
 
@@ -247,7 +263,7 @@ int CLZMA::CompressReal()
           break;
         if (finished)
         {
-          res = C_OK;
+          res = C_FINISHED;
           break;
         }
       }
