@@ -1,7 +1,25 @@
+/*
+ * compressor.h
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #ifndef __COMPRESSOR_H__
 #define __COMPRESSOR_H__
 
 #define C_OK 0
+#define C_FINISHED 1
+
 #define C_FINISH true
 
 class ICompressor {
