@@ -52,6 +52,8 @@ char *ValidateTempDir()
   return my_GetTempFileName(state_language, state_temp_dir);
 }
 
+void *g_SHGetFolderPath;
+
 int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInst,LPSTR lpszCmdParam, int nCmdShow)
 {
   int ret = 0;
@@ -65,6 +67,8 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInst,LPSTR lpszCmdParam,
 
   InitCommonControls();
 
+  SetErrorMode(SEM_NOOPENFILEERRORBOX | SEM_FAILCRITICALERRORS);
+
 #if defined(NSIS_SUPPORT_ACTIVEXREG) || defined(NSIS_SUPPORT_CREATESHORTCUT)
   {
     extern HRESULT g_hres;
@@ -72,6 +76,19 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInst,LPSTR lpszCmdParam,
   }
 #endif
 
+  // load shfolder.dll before any script code is executed to avoid
+  // weird situations where SetOutPath or even the extraction of 
+  // shfolder.dll will cause unexpected behavior.
+  //
+  // this also prevents the following:
+  //
+  //  SetOutPath "C:\Program Files\NSIS" # maybe read from reg
+  //  File shfolder.dll
+  //  Delete $PROGRAMFILES\shfolder.dll # can't be deleted, as the
+  //                                    # new shfolder.dll is used
+  //                                    # to find its own path.
+  g_SHGetFolderPath = myGetProcAddress(MGA_SHGetFolderPathA);
+
   {
     // workaround for bug #1008632
     // http://sourceforge.net/tracker/index.php?func=detail&aid=1008632&group_id=22049&atid=373085
