@@ -780,6 +780,13 @@ static BOOL CALLBACK LicenseProc(HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM
     //push button. When the user presses return ask the outer dialog to move
     //the installer onto the next page. MSDN docs say return non-zero if the
     //rich edit control should NOT process this message, hence the return 1.
+    //
+    //This is required because the RichEdit control is eating all the key hits.
+    //It does try to release some and convert VK_ESCAPE to WM_CLOSE, VK_ENTER
+    //to a push on the default button and VM_TAB to WM_NEXTDLGCTL. But sadly it
+    //it sends all of these messages to its parent instead of just letting the
+    //dialog manager handle them. Instead of properly handling WM_GETDLGCODE,
+    //it mimics the dialog manager.
     if (nmhdr->code==EN_MSGFILTER)
     {
       if (msgfilter->msg==WM_KEYDOWN)
@@ -1443,15 +1450,13 @@ static BOOL CALLBACK SelProc(HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lPar
 
 #endif//NSIS_CONFIG_VISIBLE_SUPPORT
 
-int ui_st_updateflag=0x6;
-
 void NSISCALL update_status_text(int strtab, const char *text) {
   static char tmp[NSIS_MAX_STRLEN*2];
   LVITEM new_item;
   HWND linsthwnd = insthwnd;
   if (linsthwnd)
   {
-    int updateflag = ui_st_updateflag;
+    int updateflag = g_exec_flags.status_update;
     int tmplen;
 
     if (!(updateflag & 1))
@@ -1465,8 +1470,8 @@ void NSISCALL update_status_text(int strtab, const char *text) {
       mystrcat(tmp, text);
     }
 
-    if ((updateflag & 4)) my_SetWindowText(insthwnd2, tmp);
-    if ((updateflag & 2))
+    if ((updateflag & 4) == 0) my_SetWindowText(insthwnd2, tmp);
+    if ((updateflag & 2) == 0)
     {
       new_item.mask = LVIF_TEXT;
       new_item.pszText = tmp;
