@@ -1,3 +1,19 @@
+/*
+ * components.c
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #include "../Platform.h"
 #include "config.h"
 #include "ui.h"
@@ -34,17 +50,17 @@ void NSISCALL SectionFlagsChanged(unsigned int index) {
   }
 }
 
-static unsigned int NSISCALL _RefreshSectionGroups(unsigned int i, int first_call) {
+unsigned int NSISCALL _RefreshSectionGroups(unsigned int i, int not_first_call) {
   unsigned int selected = 0;
   unsigned int not_selected = 0;
 
   section *sections = g_sections;
 
-  unsigned int sec = i;
+  section *sec = &sections[i];
 
-  if (sections[sec].flags & SF_SECGRP) {
-    if (!first_call) {
-      sections[sec].flags &= ~(SF_SELECTED | SF_PSELECTED);
+  if (sec->flags & SF_SECGRP) {
+    if (not_first_call) {
+      sec->flags &= ~(SF_SELECTED | SF_PSELECTED);
       i++;
     }
   }
@@ -54,17 +70,17 @@ static unsigned int NSISCALL _RefreshSectionGroups(unsigned int i, int first_cal
     int ni = i + 1;
 
     if (flags & SF_SECGRP) {
-      ni = _RefreshSectionGroups(i, 0);
+      ni = _RefreshSectionGroups(i, 1);
       flags = sections[i].flags;
     }
 
     if (flags & SF_SECGRPEND) {
       if (selected) {
         if (not_selected) {
-          sections[sec].flags |= SF_PSELECTED;
+          sec->flags |= SF_PSELECTED;
         } else {
-          sections[sec].flags |= SF_SELECTED;
-          sections[sec].flags &= ~SF_TOGGLED;
+          sec->flags |= SF_SELECTED;
+          sec->flags &= ~SF_TOGGLED;
         }
       }
 
@@ -87,9 +103,7 @@ static unsigned int NSISCALL _RefreshSectionGroups(unsigned int i, int first_cal
   return 0;
 }
 
-void NSISCALL RefreshSectionGroups() {
-  _RefreshSectionGroups(0, 1);
-}
+#ifdef NSIS_CONFIG_COMPONENTPAGE
 
 void NSISCALL SetInstType(int inst_type) {
   unsigned int i = 0;
@@ -146,3 +160,5 @@ unsigned int NSISCALL GetInstType(HTREEITEM *items) {
 
   return i;
 }
+
+#endif//NSIS_CONFIG_COMPONENTPAGE
