@@ -1,3 +1,19 @@
+/*
+ * fileform.h
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #include "fileform.h"
 
 extern NSIS_STRING g_usrvars[1];
@@ -11,7 +27,9 @@ extern NSIS_STRING g_usrvars[1];
 #ifdef NSIS_CONFIG_PLUGIN_SUPPORT
 #  define state_plugins_dir       g_usrvars[26]
 #endif
-#define state_click_next          g_usrvars[28]
+#define state_exe_path            g_usrvars[27]
+#define state_exe_file            g_usrvars[28]
+#define state_click_next          g_usrvars[30]
 
 extern char g_caption[NSIS_MAX_STRLEN*2];
 #ifdef NSIS_CONFIG_VISIBLE_SUPPORT
