@@ -596,6 +596,9 @@ char ps_tmpbuf[NSIS_MAX_STRLEN*2];
 const char SYSREGKEY[]   = "Software\\Microsoft\\Windows\\CurrentVersion";
 const char QUICKLAUNCH[] = "\\Microsoft\\Internet Explorer\\Quick Launch";
 
+typedef HRESULT (__stdcall * PFNSHGETFOLDERPATHA)(HWND, int, HANDLE, DWORD, LPSTR);
+extern void *g_SHGetFolderPath;
+
 // Based on Dave Laundon's simplified process_string
 char * NSISCALL GetNSISString(char *outbuf, int strtab)
 {
@@ -625,6 +628,37 @@ char * NSISCALL GetNSISString(char *outbuf, int strtab)
         LPITEMIDLIST idl;
 
         int x = 2;
+        DWORD ver = GetVersion();
+
+        /*
+
+        SHGetFolderPath as provided by shfolder.dll is used to get special folders
+        unless the installer is running on Windows 95/98. For 95/98 shfolder.dll is
+        only used for the Application Data and Documents folder (if the DLL exists).
+        Oherwise, the old SHGetSpecialFolderLocation API is called.
+
+        There reason for not using shfolder.dll for all folders on 95/98 is that
+        some unsupported folders (such as the Start Menu folder for all users) are
+        simulated instead of returning an error so whe can fall back on the folder
+        for the current user.
+
+        SHGetFolderPath in shell32.dll could be called directly for Windows versions
+        later than 95/98 but there is no need to do so, because shfolder.dll is still
+        provided and calls shell32.dll.
+
+        */
+
+        BOOL use_shfolder =
+          // Use shfolder if not on 95/98
+          !((ver & 0x80000000) && (LOWORD(ver) != 0x5A04)) ||
+
+          // Unless the Application Data or Documents folder is requested
+          (
+            (fldrs[2] == CSIDL_COMMON_APPDATA) ||
+            (fldrs[2] == CSIDL_COMMON_DOCUMENTS)
+          );
+
+        /* Carry on... shfolder stuff is over. */
 
         if (g_exec_flags.all_user_var)
         {
@@ -651,15 +685,22 @@ char * NSISCALL GetNSISString(char *outbuf, int strtab)
 
         while (x--)
         {
-          if (!SHGetSpecialFolderLocation(g_hwnd, fldrs[x], &idl))
+          if (g_SHGetFolderPath && use_shfolder)
           {
-            BOOL res = SHGetPathFromIDList(idl, out);
-            CoTaskMemFree(idl);
-            if (res)
+            PFNSHGETFOLDERPATHA SHGetFolderPathFunc = (PFNSHGETFOLDERPATHA) g_SHGetFolderPath;
+            if (!SHGetFolderPathFunc(g_hwnd, fldrs[x], NULL, SHGFP_TYPE_CURRENT, out))
             {
               break;
             }
           }
+            
+          if (!SHGetSpecialFolderLocation(g_hwnd, fldrs[x], &idl))
+          {
+            BOOL res = SHGetPathFromIDList(idl, out);
+            CoTaskMemFree(idl);
+            if (res) break;
+          }
+
           *out=0;
         }
 
@@ -672,7 +713,6 @@ char * NSISCALL GetNSISString(char *outbuf, int strtab)
             mystrcat(out, QUICKLAUNCH);
           }
         }
-
         validate_filename(out);
       }
       else if (nVarIdx == NS_VAR_CODE)
@@ -873,10 +913,7 @@ WIN32_FIND_DATA * NSISCALL file_exists(char *buf)
 {
   HANDLE h;
   static WIN32_FIND_DATA fd;
-  // Avoid a "There is no disk in the drive" error box on empty removable drives
-  SetErrorMode(SEM_NOOPENFILEERRORBOX | SEM_FAILCRITICALERRORS);
   h = FindFirstFile(buf,&fd);
-  SetErrorMode(0);
   if (h != INVALID_HANDLE_VALUE)
   {
     FindClose(h);
@@ -899,7 +936,8 @@ struct MGA_FUNC MGA_FUNCS[] = {
   {"ADVAPI32", "LookupPrivilegeValueA"},
   {"ADVAPI32", "AdjustTokenPrivileges"},
   {"KERNEL32", "GetUserDefaultUILanguage"},
-  {"SHLWAPI",  "SHAutoComplete"}
+  {"SHLWAPI",  "SHAutoComplete"},
+  {"SHFOLDER", "SHGetFolderPathA"}
 };
 
 void * NSISCALL myGetProcAddress(const enum myGetProcAddressFunctions func)
