@@ -1,3 +1,19 @@
+/*
+ * lang.h
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #ifndef ___NLF___H_____
 #define ___NLF___H_____
 
@@ -154,6 +170,7 @@ enum {
   NLF_FONT = NLF_STRINGS_NO_SPECIAL,
   NLF_FONTSIZE,
   NLF_RTL,
+  NLF_LANGUAGE,
 
   NLF_STRINGS
 };
