@@ -1,3 +1,19 @@
+/*
+ * tokens.h
+ * 
+ * This file is a part of NSIS.
+ * 
+ * Copyright (C) 1999-2007 Nullsoft and Contributors
+ * 
+ * Licensed under the zlib/libpng license (the "License");
+ * you may not use this file except in compliance with the License.
+ * 
+ * Licence details can be found in the file COPYING.
+ * 
+ * This software is provided 'as-is', without any express or implied
+ * warranty.
+ */
+
 #ifndef _TOKENS_H_
 #define _TOKENS_H_
 
@@ -42,6 +58,7 @@ enum
   TOK_FILEERRORTEXT,
   TOK_INSTPROGRESSFLAGS,
   TOK_XPSTYLE,
+  TOK_REQEXECLEVEL,
   TOK_CHANGEUI,
   TOK_ADDBRANDINGIMAGE,
   TOK_SETFONT,
@@ -237,6 +254,7 @@ enum
   TOK_INSTTYPEGETTEXT,
   TOK_GETCURINSTTYPE,
   TOK_SETCURINSTTYPE,
+  TOK_SETREGVIEW,
   TOK_SETSHELLVARCONTEXT,
   TOK_PLUGINDIR,
   TOK_INITPLUGINSDIR,
