@@ -36,16 +36,6 @@ extern void dopause(void);
 // If width or height are specified it will also make sure the bitmap is in that size
 int update_bitmap(CResourceEditor* re, WORD id, const char* filename, int width=0, int height=0, int maxbpp=0);
 
-// reads icon file filename and places its icons in the resource wIconId using resource editor re
-void replace_icon(CResourceEditor* re, WORD wIconId, const char* filename);
-
-#ifdef NSIS_CONFIG_UNINSTALL_SUPPORT
-// returns the data of the uninstaller icon (inside filename) that should replace the installer icon data
-unsigned char* generate_uninstall_icon_data(const char* filename, size_t &size);
-// Fill the array of icons for uninstall with their offsets
-int generate_unicons_offsets(unsigned char* exeHeader, size_t exeHeaderSize, unsigned char* uninstIconData);
-#endif//NSIS_CONFIG_UNINSTALL_SUPPORT
-
 size_t my_strftime(char *s, size_t max, const char  *fmt, const struct tm *tm);
 
 bool GetDLLVersion(const std::string& filepath, DWORD& high, DWORD& low);
@@ -65,12 +55,14 @@ int sane_system(const char *command);
 #ifndef _WIN32
 char *CharPrev(const char *s, const char *p);
 char *CharNext(const char *s);
+char *CharNextExA(WORD codepage, const char *s, int flags);
 int wsprintf(char *s, const char *format, ...);
 int WideCharToMultiByte(UINT CodePage, DWORD dwFlags, LPCWSTR lpWideCharStr,
     int cchWideChar, LPSTR lpMultiByteStr, int cbMultiByte, LPCSTR lpDefaultChar,
     LPBOOL lpUsedDefaultChar);
 int MultiByteToWideChar(UINT CodePage, DWORD dwFlags, LPCSTR lpMultiByteStr,
     int cbMultiByte, LPWSTR lpWideCharStr, int cchWideChar);
+BOOL IsValidCodePage(UINT CodePage);
 
 char *my_convert(const char *path);
 void my_convert_free(char *converted_path);
